// Fetch data
d3.csv(
  'https://gist.githubusercontent.com/OMWERIDOUGLAS/753a79386eae259d8823f6566a2e375e/raw/b3a85ba738bf2c215d1b540a6cf10f91407f9806/Activity6_Population-1.csv',
)
  .then(function (data) {
    data.sort((a, b) => b['2010'] - a['2010']);
    const top30 = data.slice(0, 20);

    // Define SVG dimensions and margins
    const svgWidth = 900;
    const svgHeight = 500;
    const margin = {
      top: 20,
      right: 20,
      bottom: 70,
      left: 100,
    };
    const width = svgWidth - margin.left - margin.right;
    const height = svgHeight - margin.top - margin.bottom;

    // Create SVG element
    const svg = d3
      .select('svg')
      .attr('width', svgWidth)
      .attr('height', svgHeight);

    // Create scales
    const xScale = d3
      .scaleLinear()
      .domain([0, d3.max(top30, (d) => d['2010'])])
      .range([0, width]);

    const yScale = d3
      .scaleBand()
      .domain(top30.map((d) => d.Country))
      .range([0, height])
      .padding(0.2);

    // Create x-axis
    svg
      .append('g')
      .attr(
        'transform',
        `translate(${margin.left}, ${margin.top + height})`,
      )
      .call(
        d3
          .axisBottom(xScale)
          .tickFormat((d) => d / 1000000 + 'M'),
      );

    // Create y-axis
    svg
      .append('g')
      .attr(
        'transform',
        `translate(${margin.left}, ${margin.top})`,
      )
      .call(d3.axisLeft(yScale));

    // Create x-axis label
    svg
      .append('text')
      .attr('x', svgWidth / 2)
      .attr('y', svgHeight - margin.bottom / 2)
      .attr('text-anchor', 'middle')
      .text('Population in 2010 (Millions)');

    // Create y-axis label
    svg
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('x', -svgHeight / 2)
      .attr('y', margin.left / 2)
      .attr('text-anchor', 'middle')
      .text('Country');

    // Create bars
    svg
      .selectAll('rect')
      .data(top30)
      .enter()
      .append('rect')
      .attr('x', margin.left)
      .attr('y', (d) => margin.top + yScale(d.Country))
      .attr('width', (d) => xScale(d['2010']))
      .attr('height', yScale.bandwidth())
      .attr('fill', 'steelblue');
  })
  .catch(function (error) {
    console.log(error);
  });
